<a id="mypy-boto3-lex-models"></a>

# mypy-boto3-lex-models

[![PyPI - types-aiobotocore-lex-models](https://img.shields.io/pypi/v/types-aiobotocore-lex-models.svg?color=blue)](https://pypi.org/project/types-aiobotocore-lex-models)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-lex-models.svg?color=blue)](https://pypi.org/project/types-aiobotocore-lex-models)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-lex-models?color=blue)](https://pypistats.org/packages/types-aiobotocore-lex-models)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.LexModelBuildingService 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lex-models.html#LexModelBuildingService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-lex-models docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_lex_models/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-lex-models](#mypy-boto3-lex-models)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `LexModelBuildingService`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `LexModelBuildingService` service.

```bash
python -m pip install types-aiobotocore[lex-models]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[lex-models]` in your environment:
  `python -m pip install 'types-aiobotocore[lex-models]'`

Both type checking and auto-complete should work for `LexModelBuildingService`
service. No explicit type annotations required, write your `boto3` code as
usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[lex-models]` in your environment:
  `python -m pip install 'types-aiobotocore[lex-models]'`

Both type checking and auto-complete should work for `LexModelBuildingService`
service. No explicit type annotations required, write your `aiobotocore` code
as usual. Auto-complete can be slow on big projects or if you have a lot of
installed `types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[lex-models]` in your environment:
  `python -m pip install 'types-aiobotocore[lex-models]'`
- Run `mypy` as usual

Type checking should work for `LexModelBuildingService` service. No explicit
type annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[lex-models]` in your environment:
  `python -m pip install 'types-aiobotocore[lex-models]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `LexModelBuildingService` service. No explicit
type annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`LexModelBuildingServiceClient` provides annotations for
`session.create_client("lex-models")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_lex_models import LexModelBuildingServiceClient

session = get_session()
with async session.create_client("lex-models") as client:
    client: LexModelBuildingServiceClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_lex_models.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_lex_models import LexModelBuildingServiceClient
from types_aiobotocore_lex_models.paginator import (
    GetBotAliasesPaginator,
    GetBotChannelAssociationsPaginator,
    GetBotVersionsPaginator,
    GetBotsPaginator,
    GetBuiltinIntentsPaginator,
    GetBuiltinSlotTypesPaginator,
    GetIntentVersionsPaginator,
    GetIntentsPaginator,
    GetSlotTypeVersionsPaginator,
    GetSlotTypesPaginator,
)

session = get_session()
with async session.create_client("lex-models") as client:
    client: LexModelBuildingServiceClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        get_bot_aliases_paginator: GetBotAliasesPaginator = client.get_paginator("get_bot_aliases")
        get_bot_channel_associations_paginator: GetBotChannelAssociationsPaginator = client.get_paginator("get_bot_channel_associations")
        get_bot_versions_paginator: GetBotVersionsPaginator = client.get_paginator("get_bot_versions")
        get_bots_paginator: GetBotsPaginator = client.get_paginator("get_bots")
        get_builtin_intents_paginator: GetBuiltinIntentsPaginator = client.get_paginator("get_builtin_intents")
        get_builtin_slot_types_paginator: GetBuiltinSlotTypesPaginator = client.get_paginator("get_builtin_slot_types")
        get_intent_versions_paginator: GetIntentVersionsPaginator = client.get_paginator("get_intent_versions")
        get_intents_paginator: GetIntentsPaginator = client.get_paginator("get_intents")
        get_slot_type_versions_paginator: GetSlotTypeVersionsPaginator = client.get_paginator("get_slot_type_versions")
        get_slot_types_paginator: GetSlotTypesPaginator = client.get_paginator("get_slot_types")
    ```







### Literals

`types_aiobotocore_lex_models.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_lex_models.literals import (
    ChannelStatusType,
    ChannelTypeType,
    ContentTypeType,
    DestinationType,
    ExportStatusType,
    ExportTypeType,
    FulfillmentActivityTypeType,
    GetBotAliasesPaginatorName,
    GetBotChannelAssociationsPaginatorName,
    GetBotVersionsPaginatorName,
    GetBotsPaginatorName,
    GetBuiltinIntentsPaginatorName,
    GetBuiltinSlotTypesPaginatorName,
    GetIntentVersionsPaginatorName,
    GetIntentsPaginatorName,
    GetSlotTypeVersionsPaginatorName,
    GetSlotTypesPaginatorName,
    ImportStatusType,
    LocaleType,
    LogTypeType,
    MergeStrategyType,
    MigrationAlertTypeType,
    MigrationSortAttributeType,
    MigrationStatusType,
    MigrationStrategyType,
    ObfuscationSettingType,
    ProcessBehaviorType,
    ResourceTypeType,
    SlotConstraintType,
    SlotValueSelectionStrategyType,
    SortOrderType,
    StatusType,
    StatusTypeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ChannelStatusType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_lex_models.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_lex_models.type_defs import (
    BotAliasMetadataTypeDef,
    BotChannelAssociationTypeDef,
    BotMetadataTypeDef,
    BuiltinIntentMetadataTypeDef,
    BuiltinIntentSlotTypeDef,
    BuiltinSlotTypeMetadataTypeDef,
    CodeHookTypeDef,
    ConversationLogsRequestTypeDef,
    ConversationLogsResponseTypeDef,
    CreateBotVersionRequestRequestTypeDef,
    CreateBotVersionResponseTypeDef,
    CreateIntentVersionRequestRequestTypeDef,
    CreateIntentVersionResponseTypeDef,
    CreateSlotTypeVersionRequestRequestTypeDef,
    CreateSlotTypeVersionResponseTypeDef,
    DeleteBotAliasRequestRequestTypeDef,
    DeleteBotChannelAssociationRequestRequestTypeDef,
    DeleteBotRequestRequestTypeDef,
    DeleteBotVersionRequestRequestTypeDef,
    DeleteIntentRequestRequestTypeDef,
    DeleteIntentVersionRequestRequestTypeDef,
    DeleteSlotTypeRequestRequestTypeDef,
    DeleteSlotTypeVersionRequestRequestTypeDef,
    DeleteUtterancesRequestRequestTypeDef,
    EnumerationValueTypeDef,
    FollowUpPromptTypeDef,
    FulfillmentActivityTypeDef,
    GetBotAliasRequestRequestTypeDef,
    GetBotAliasResponseTypeDef,
    GetBotAliasesRequestRequestTypeDef,
    GetBotAliasesResponseTypeDef,
    GetBotChannelAssociationRequestRequestTypeDef,
    GetBotChannelAssociationResponseTypeDef,
    GetBotChannelAssociationsRequestRequestTypeDef,
    GetBotChannelAssociationsResponseTypeDef,
    GetBotRequestRequestTypeDef,
    GetBotResponseTypeDef,
    GetBotVersionsRequestRequestTypeDef,
    GetBotVersionsResponseTypeDef,
    GetBotsRequestRequestTypeDef,
    GetBotsResponseTypeDef,
    GetBuiltinIntentRequestRequestTypeDef,
    GetBuiltinIntentResponseTypeDef,
    GetBuiltinIntentsRequestRequestTypeDef,
    GetBuiltinIntentsResponseTypeDef,
    GetBuiltinSlotTypesRequestRequestTypeDef,
    GetBuiltinSlotTypesResponseTypeDef,
    GetExportRequestRequestTypeDef,
    GetExportResponseTypeDef,
    GetImportRequestRequestTypeDef,
    GetImportResponseTypeDef,
    GetIntentRequestRequestTypeDef,
    GetIntentResponseTypeDef,
    GetIntentVersionsRequestRequestTypeDef,
    GetIntentVersionsResponseTypeDef,
    GetIntentsRequestRequestTypeDef,
    GetIntentsResponseTypeDef,
    GetMigrationRequestRequestTypeDef,
    GetMigrationResponseTypeDef,
    GetMigrationsRequestRequestTypeDef,
    GetMigrationsResponseTypeDef,
    GetSlotTypeRequestRequestTypeDef,
    GetSlotTypeResponseTypeDef,
    GetSlotTypeVersionsRequestRequestTypeDef,
    GetSlotTypeVersionsResponseTypeDef,
    GetSlotTypesRequestRequestTypeDef,
    GetSlotTypesResponseTypeDef,
    GetUtterancesViewRequestRequestTypeDef,
    GetUtterancesViewResponseTypeDef,
    InputContextTypeDef,
    IntentMetadataTypeDef,
    IntentTypeDef,
    KendraConfigurationTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    LogSettingsRequestTypeDef,
    LogSettingsResponseTypeDef,
    MessageTypeDef,
    MigrationAlertTypeDef,
    MigrationSummaryTypeDef,
    OutputContextTypeDef,
    PaginatorConfigTypeDef,
    PromptTypeDef,
    PutBotAliasRequestRequestTypeDef,
    PutBotAliasResponseTypeDef,
    PutBotRequestRequestTypeDef,
    PutBotResponseTypeDef,
    PutIntentRequestRequestTypeDef,
    PutIntentResponseTypeDef,
    PutSlotTypeRequestRequestTypeDef,
    PutSlotTypeResponseTypeDef,
    ResponseMetadataTypeDef,
    SlotDefaultValueSpecTypeDef,
    SlotDefaultValueTypeDef,
    SlotTypeConfigurationTypeDef,
    SlotTypeDef,
    SlotTypeMetadataTypeDef,
    SlotTypeRegexConfigurationTypeDef,
    StartImportRequestRequestTypeDef,
    StartImportResponseTypeDef,
    StartMigrationRequestRequestTypeDef,
    StartMigrationResponseTypeDef,
    StatementTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UtteranceDataTypeDef,
    UtteranceListTypeDef,
)

def get_structure() -> BotAliasMetadataTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-lex-models` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-lex-models docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_lex_models/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
